import React from 'react';

import { AutofillRetrieveResponse } from '@mapbox/search-js-core';
import {
  AddressAutofill,
  useConfirmAddress,
  AddressMinimap,
  config
} from '../src';

declare global {
  const MAPBOX_ACCESS_TOKEN: string;
}

// Autofilled by ESBuild.
const ACCESS_TOKEN = MAPBOX_ACCESS_TOKEN;
config.accessToken = ACCESS_TOKEN;

export function Component(): React.ReactElement {
  const [value, setValue] = React.useState('');
  const [text, setText] = React.useState('');
  const [showMinimap, setShowMinimap] = React.useState(false);
  const [feature, setFeature] =
    React.useState<GeoJSON.Feature<GeoJSON.Point>>();

  const { formRef, showConfirm } = useConfirmAddress();

  const handleRetrieve = React.useCallback(
    (res: AutofillRetrieveResponse) => {
      const feature = res.features[0];
      setText(feature.properties.full_address);
      setFeature(feature);
      setShowMinimap(true);
    },
    [setText, setFeature, setShowMinimap]
  );

  const handleSaveMarkerLocation = React.useCallback(
    (coordinate: [number, number]) => {
      if (coordinate.toString() !== feature.geometry.coordinates.toString()) {
        console.log(`Marker updated to ${JSON.stringify(coordinate)}.`);
      }
    },
    [feature]
  );

  const handleSubmit = React.useCallback(async () => {
    const result = await showConfirm();
    console.log(result);
  }, [showConfirm]);

  return (
    <div style={{ display: 'flex', flexDirection: 'column' }}>
      <form ref={formRef}>
        <AddressAutofill accessToken={ACCESS_TOKEN} onRetrieve={handleRetrieve}>
          <input
            autoComplete="shipping address-line1"
            value={value}
            onChange={(e) => setValue(e.target.value)}
            style={{
              border: '1px solid black',
              marginTop: 200,
              borderRadius: 6
            }}
          />
        </AddressAutofill>
        <p>{text}</p>
      </form>
      <button onClick={handleSubmit}>Submit</button>
      <div style={{ height: 400, width: 800 }}>
        <AddressMinimap
          canAdjustMarker={true}
          satelliteToggle={true}
          feature={feature}
          show={showMinimap}
          onSaveMarkerLocation={handleSaveMarkerLocation}
        />
      </div>
    </div>
  );
}
